aboutsummaryrefslogtreecommitdiff
path: root/engines/glk/time.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/glk/time.h')
-rw-r--r--engines/glk/time.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/engines/glk/time.h b/engines/glk/time.h
index 119fab76e5..8e68328dcf 100644
--- a/engines/glk/time.h
+++ b/engines/glk/time.h
@@ -25,7 +25,7 @@
#include "glk/glk_types.h"
-namespace Gargoyle {
+namespace Glk {
typedef int64 TimeSeconds;
@@ -88,6 +88,6 @@ public:
};
typedef TimeAndDate glkdate_t;
-} // End of namespace Gargoyle
+} // End of namespace Glk
#endif